@@ -96,7 +96,7 @@ QList< QPair< QString, QWidget* > > HandleButtonEventsConfig::buildUi()
 
         QSet< Solid::PowerManagement::SleepState > methods = Solid::PowerManagement::supportedSleepStates();
 
-        foreach (QComboBox *box, boxes) {
+        Q_FOREACH (QComboBox *box, boxes) {
             box->addItem(QIcon::fromTheme("dialog-cancel"), i18n("Do nothing"), (uint)SuspendSession::None);
             if (methods.contains(Solid::PowerManagement::SuspendState)) {
                 box->addItem(QIcon::fromTheme("system-suspend"), i18n("Suspend"), (uint)SuspendSession::ToRamMode);
@@ -104,7 +104,7 @@ QList< QPair< QString, QWidget* > > HandleButtonEventsConfig::buildUi()
             if (methods.contains(Solid::PowerManagement::HibernateState)) {
                 box->addItem(QIcon::fromTheme("system-suspend-hibernate"), i18n("Hibernate"), (uint)SuspendSession::ToDiskMode);
             }
-            box->addItem(QIcon::fromTheme("system-shutdown"), i18n("Shutdown"), (uint)SuspendSession::ShutdownMode);
+            box->addItem(QIcon::fromTheme("system-shutdown"), i18n("Shut down"), (uint)SuspendSession::ShutdownMode);
             box->addItem(QIcon::fromTheme("system-lock-screen"), i18n("Lock screen"), (uint)SuspendSession::LockScreenMode);
             if (box != m_lidCloseCombo) {
                 box->addItem(QIcon::fromTheme("system-log-out"), i18n("Prompt log out dialog"), (uint)SuspendSession::LogoutDialogMode);
@@ -120,7 +120,7 @@ QList< QPair< QString, QWidget* > > HandleButtonEventsConfig::buildUi()
     bool lidFound = false;
     bool powerFound = true; // HACK This needs proper API!!
     // get a list of all devices that are Buttons
-/*    foreach (Solid::Device device, Solid::Device::listFromType(Solid::DeviceInterface::Button, QString())) {
+/*    Q_FOREACH (Solid::Device device, Solid::Device::listFromType(Solid::DeviceInterface::Button, QString())) {
         Solid::Button *button = device.as<Solid::Button>();
         if (button->type() == Solid::Button::LidButton) {
             lidFound = true;
